@@ -37,6 +37,8 @@ from cinder import exception
 
 # Add new constants here for each new microversion.
 
+V2_BASE_VERSION = '2.0'
+
 BASE_VERSION = '3.0'
 
 UPLOAD_IMAGE_PARAMS = '3.1'
@@ -139,6 +141,24 @@ BACKEND_STATE_REPORT = '3.49'
 
 MULTIATTACH_VOLUMES = '3.50'
 
+BACKUP_AZ = '3.51'
+
+SUPPORT_VOLUME_TYPE_FILTER = '3.52'
+
+SUPPORT_VOLUME_SCHEMA_CHANGES = '3.53'
+
+ATTACHMENT_CREATE_MODE_ARG = '3.54'
+
+TRANSFER_WITH_SNAPSHOTS = '3.55'
+
+BACKUP_PROJECT_USER_ID = '3.56'
+
+TRANSFER_WITH_HISTORY = '3.57'
+
+GROUP_GROUPSNAPSHOT_PROJECT_ID = '3.58'
+
+SUPPORT_TRANSFER_PAGINATION = '3.59'
+
 
 def get_mv_header(version):
     """Gets a formatted HTTP microversion header.
