@@ -136,7 +136,7 @@ class VolumeMetadataBackup(object):
             msg = _("Metadata backup object '%s' already exists") % self.name
             raise exception.VolumeMetadataBackupExists(msg)
 
-        meta_obj.write(json_meta)
+        meta_obj.write(json_meta.encode('utf-8'))
 
     def get(self):
         """Get metadata backup object.
@@ -149,7 +149,7 @@ class VolumeMetadataBackup(object):
             LOG.debug("Metadata backup object %s does not exist", self.name)
             return None
 
-        return meta_obj.read()
+        return meta_obj.read().decode('utf-8')
 
     def remove_if_exists(self):
         meta_obj = eventlet.tpool.Proxy(rados.Object(self._client.ioctx,
@@ -194,6 +194,10 @@ class CephBackupDriver(driver.BackupDriver):
         self._ceph_backup_pool = utils.convert_str(CONF.backup_ceph_pool)
         self._ceph_backup_conf = utils.convert_str(CONF.backup_ceph_conf)
 
+    @staticmethod
+    def get_driver_options():
+        return service_opts
+
     def _validate_string_args(self, *args):
         """Ensure all args are non-None and non-empty."""
         return all(args)
@@ -337,7 +341,15 @@ class CephBackupDriver(driver.BackupDriver):
             LOG.debug("Discarding %(length)s bytes from offset %(offset)s",
                       {'length': length, 'offset': offset})
             if self._file_is_rbd(volume):
-                eventlet.tpool.Proxy(volume.rbd_image).discard(offset, length)
+                limit = 2 * units.Gi - 1
+                chunks = int(length / limit)
+                for chunk in range(0, chunks):
+                    eventlet.tpool.Proxy(volume.rbd_image).discard(
+                        offset + chunk * limit, limit)
+                rem = int(length % limit)
+                if rem:
+                    eventlet.tpool.Proxy(volume.rbd_image).discard(
+                        offset + chunks * limit, rem)
             else:
                 zeroes = '\0' * self.chunk_size
                 chunks = int(length / self.chunk_size)
@@ -545,7 +557,8 @@ class CephBackupDriver(driver.BackupDriver):
 
         try:
             p1 = subprocess.Popen(cmd1, stdout=subprocess.PIPE,
-                                  stderr=subprocess.PIPE)
+                                  stderr=subprocess.PIPE,
+                                  close_fds=True)
         except OSError as e:
             LOG.error("Pipe1 failed - %s ", e)
             raise
@@ -559,7 +572,8 @@ class CephBackupDriver(driver.BackupDriver):
         try:
             p2 = subprocess.Popen(cmd2, stdin=p1.stdout,
                                   stdout=subprocess.PIPE,
-                                  stderr=subprocess.PIPE)
+                                  stderr=subprocess.PIPE,
+                                  close_fds=True)
         except OSError as e:
             LOG.error("Pipe2 failed - %s ", e)
             raise
@@ -631,16 +645,16 @@ class CephBackupDriver(driver.BackupDriver):
                                         base_name, read_only=True))
         try:
             snaps = base_rbd.list_snaps()
+
+            if snaps is None:
+                return False
+
+            for snap in snaps:
+                if snap['name'] == snap_name:
+                    return True
         finally:
             base_rbd.close()
 
-        if snaps is None:
-            return False
-
-        for snap in snaps:
-            if snap['name'] == snap_name:
-                return True
-
         return False
 
     def _backup_rbd(self, backup, volume_file, volume_name, length):
