@@ -27,6 +27,7 @@ import sys
 import eventlet
 eventlet.monkey_patch()
 
+from oslo_concurrency import processutils
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_privsep import priv_context
@@ -39,6 +40,7 @@ i18n.enable_lazy()
 
 # Need to register global_opts
 from cinder.common import config  # noqa
+from cinder.db import api as session
 from cinder import objects
 from cinder import service
 from cinder import utils
@@ -47,6 +49,15 @@ from cinder import version
 
 CONF = cfg.CONF
 
+backup_workers_opt = cfg.IntOpt(
+    'backup_workers',
+    default=1, min=1, max=processutils.get_worker_count(),
+    help='Number of backup processes to launch. Improves performance with '
+    'concurrent backups.')
+CONF.register_opt(backup_workers_opt)
+
+LOG = None
+
 # NOTE(mriedem): The default backup driver uses swift and performs read/write
 # operations in a thread. swiftclient will log requests and responses at DEBUG
 # level, which can cause a thread switch and break the backup operation. So we
@@ -54,6 +65,22 @@ CONF = cfg.CONF
 _EXTRA_DEFAULT_LOG_LEVELS = ['swiftclient=WARN']
 
 
+def _launch_backup_process(launcher, num_process):
+    try:
+        server = service.Service.create(binary='cinder-backup',
+                                        coordination=True,
+                                        process_number=num_process)
+    except Exception:
+        LOG.exception('Backup service %s failed to start.', CONF.host)
+        sys.exit(1)
+    else:
+        # Dispose of the whole DB connection pool here before
+        # starting another process.  Otherwise we run into cases where
+        # child processes share DB connections which results in errors.
+        session.dispose_engine()
+        launcher.launch_service(server)
+
+
 def main():
     objects.register_all()
     gmr_opts.set_defaults(CONF)
@@ -67,7 +94,13 @@ def main():
     priv_context.init(root_helper=shlex.split(utils.get_root_helper()))
     utils.monkey_patch()
     gmr.TextGuruMeditation.setup_autorun(version, conf=CONF)
-    server = service.Service.create(binary='cinder-backup',
-                                    coordination=True)
-    service.serve(server)
-    service.wait()
+    global LOG
+    LOG = logging.getLogger(__name__)
+
+    LOG.info('Backup running with %s processes.', CONF.backup_workers)
+    launcher = service.get_launcher()
+
+    for i in range(1, CONF.backup_workers + 1):
+        _launch_backup_process(launcher, i)
+
+    launcher.wait()
