@@ -14,13 +14,16 @@
 import datetime
 import ddt
 import iso8601
+import json
 
+import fixtures
 import mock
 from oslo_serialization import jsonutils
 from oslo_utils import strutils
 from six.moves import http_client
 import webob
 
+from cinder.api import common
 from cinder.api import extensions
 from cinder.api import microversions as mv
 from cinder.api.v2.views.volumes import ViewBuilder
@@ -58,8 +61,13 @@ class VolumeApiTest(test.TestCase):
 
         self.flags(host='fake')
         self.ctxt = context.RequestContext(fake.USER_ID, fake.PROJECT_ID, True)
+        # This will be cleaned up by the NestedTempfile fixture in base class
+        self.tmp_path = self.useFixture(fixtures.TempDir()).path
 
     def test_check_volume_filters_called(self):
+        # Clear the filters collection to make sure the filters collection
+        # cache can be reloaded using tmp filter file.
+        common._FILTERS_COLLECTION = None
         with mock.patch.object(vol_get.API,
                                'check_volume_filters') as volume_get:
             req = fakes.HTTPRequest.blank('/v3/volumes?bootable=True')
@@ -68,14 +76,24 @@ class VolumeApiTest(test.TestCase):
             req.headers = mv.get_mv_header(mv.BASE_VERSION)
             req.environ['cinder.context'].is_admin = True
 
-            self.override_config('query_volume_filters', 'bootable')
+            tmp_filter_file = self.tmp_path + '/resource_filters_tests.json'
+            self.override_config('resource_query_filters_file',
+                                 tmp_filter_file)
+            with open(tmp_filter_file, 'w') as f:
+                f.write(json.dumps({"volume": ['bootable']}))
             self.controller.index(req)
             filters = req.params.copy()
 
             volume_get.assert_called_with(filters, False)
+        # Reset the CONF.resource_query_filters_file and clear the filters
+        # collection to avoid leaking other cases, and it will be re-loaded
+        # from CONF.resource_query_filters_file in next call.
+        self._reset_filter_file()
 
     def test_check_volume_filters_strict_called(self):
-
+        # Clear the filters collection to make sure the filters collection
+        # cache can be reloaded using tmp filter file.
+        common._FILTERS_COLLECTION = None
         with mock.patch.object(vol_get.API,
                                'check_volume_filters') as volume_get:
             req = fakes.HTTPRequest.blank('/v3/volumes?bootable=True')
@@ -86,11 +104,19 @@ class VolumeApiTest(test.TestCase):
             req.api_version_request = mv.get_api_version(
                 mv.VOLUME_LIST_BOOTABLE)
 
-            self.override_config('query_volume_filters', 'bootable')
+            tmp_filter_file = self.tmp_path + '/resource_filters_tests.json'
+            self.override_config('resource_query_filters_file',
+                                 tmp_filter_file)
+            with open(tmp_filter_file, 'w') as f:
+                f.write(json.dumps({"volume": ['bootable']}))
             self.controller.index(req)
             filters = req.params.copy()
 
             volume_get.assert_called_with(filters, True)
+        # Reset the CONF.resource_query_filters_file and clear the filters
+        # collection to avoid leaking other cases, and it will be re-loaded
+        # from CONF.resource_query_filters_file in next call.
+        self._reset_filter_file()
 
     def _create_volume_with_glance_metadata(self):
         vol1 = db.volume_create(self.ctxt, {'display_name': 'test1',
@@ -277,7 +303,6 @@ class VolumeApiTest(test.TestCase):
         get_snapshot.side_effect = v2_fakes.fake_snapshot_get
         volume_type_get.side_effect = v2_fakes.fake_volume_type_get
 
-        self.ext_mgr.extensions = {'os-image-create': 'fake'}
         vol = self._vol_in_request_body(
             image_id="b0a599e0-41d7-3582-b260-769f443c862a")
 
@@ -508,7 +533,14 @@ class VolumeApiTest(test.TestCase):
               (mv.get_prior_version(mv.GROUP_VOLUME),
                {'name': ' test name ',
                 'description': ' test desc ',
-                'size': 1}))
+                'size': 1}),
+              ('3.0',
+               {'name': 'test name',
+                'description': 'test desc',
+                'size': 1,
+                'user_id': 'teapot',
+                'project_id': 'kettle',
+                'status': 'confused'}))
     @ddt.unpack
     def test_volume_create(self, max_ver, volume_body):
         self.mock_object(volume_api.API, 'get', v2_fakes.fake_volume_get)
@@ -530,6 +562,28 @@ class VolumeApiTest(test.TestCase):
         self.assertEqual(ex['volume']['description'],
                          res_dict['volume']['description'])
 
+    def test_volume_create_extra_params(self):
+        self.mock_object(volume_api.API, 'get', v2_fakes.fake_volume_get)
+        self.mock_object(volume_api.API, "create",
+                         v2_fakes.fake_volume_api_create)
+        self.mock_object(db.sqlalchemy.api, '_volume_type_get_full',
+                         v2_fakes.fake_volume_type_get)
+
+        req = fakes.HTTPRequest.blank('/v3/volumes')
+        req.api_version_request = mv.get_api_version(
+            mv.SUPPORT_VOLUME_SCHEMA_CHANGES)
+
+        body = {'volume': {
+                'name': 'test name',
+                'description': 'test desc',
+                'size': 1,
+                'user_id': 'teapot',
+                'project_id': 'kettle',
+                'status': 'confused'}}
+        self.assertRaises(exception.ValidationError,
+                          self.controller.create,
+                          req, body=body)
+
     @ddt.data(mv.get_prior_version(mv.VOLUME_DELETE_FORCE),
               mv.VOLUME_DELETE_FORCE)
     @mock.patch('cinder.context.RequestContext.authorize')
