@@ -18,10 +18,8 @@ import re
 
 from oslo_config import cfg
 
-from cinder import context
 from cinder import exception
 from cinder.objects import fields
-from cinder import test
 from cinder.tests.unit import fake_constants
 from cinder.tests.unit import utils as test_utils
 from cinder.tests.unit.volume.drivers.dell_emc.vnx import fake_exception \
@@ -29,24 +27,19 @@ from cinder.tests.unit.volume.drivers.dell_emc.vnx import fake_exception \
 from cinder.tests.unit.volume.drivers.dell_emc.vnx import fake_storops \
     as storops
 from cinder.tests.unit.volume.drivers.dell_emc.vnx import res_mock
+from cinder.tests.unit.volume.drivers.dell_emc.vnx import test_base
 from cinder.tests.unit.volume.drivers.dell_emc.vnx import utils
-from cinder.volume import configuration as conf
 from cinder.volume.drivers.dell_emc.vnx import adapter
 from cinder.volume.drivers.dell_emc.vnx import client
 from cinder.volume.drivers.dell_emc.vnx import common
 from cinder.volume.drivers.dell_emc.vnx import utils as vnx_utils
 
 
-class TestCommonAdapter(test.TestCase):
+class TestCommonAdapter(test_base.TestCase):
 
     def setUp(self):
         super(TestCommonAdapter, self).setUp()
-        self.configuration = conf.Configuration(None)
         vnx_utils.init_ops(self.configuration)
-        self.configuration.san_ip = '192.168.1.1'
-        self.configuration.storage_vnx_authentication_type = 'global'
-        self.configuration.config_group = 'vnx_backend'
-        self.ctxt = context.get_admin_context()
 
     @res_mock.mock_driver_input
     @res_mock.patch_common_adapter
@@ -218,9 +211,9 @@ class TestCommonAdapter(test.TestCase):
             vnx_common.do_create_cg_from_cgsnap(
                 cg_id, cg_host, volumes, cgsnap_id, snaps))
         self.assertIsNone(model_update)
-        self.assertIsNotNone(
-            re.findall('id^12',
-                       volume_updates[0]['provider_location']))
+        provider_location = re.findall('id\^12',
+                                       volume_updates[0]['provider_location'])
+        self.assertEqual(1, len(provider_location))
 
     @res_mock.patch_common_adapter
     def test_create_cloned_cg(self, common, _):
@@ -277,9 +270,9 @@ class TestCommonAdapter(test.TestCase):
         model_update, volume_updates = vnx_common.do_clone_cg(
             cg_id, cg_host, volumes, src_cg_id, src_volumes)
         self.assertIsNone(model_update)
-        self.assertIsNotNone(
-            re.findall('id^12',
-                       volume_updates[0]['provider_location']))
+        provider_location = re.findall('id\^12',
+                                       volume_updates[0]['provider_location'])
+        self.assertEqual(1, len(provider_location))
 
     @res_mock.patch_common_adapter
     def test_parse_pools(self, vnx_common, mocked):
@@ -1427,18 +1420,14 @@ class TestCommonAdapter(test.TestCase):
                           common_adapter._normalize_config)
 
 
-class TestISCSIAdapter(test.TestCase):
+class TestISCSIAdapter(test_base.TestCase):
     STORAGE_PROTOCOL = common.PROTOCOL_ISCSI
 
     def setUp(self):
         super(TestISCSIAdapter, self).setUp()
-        self.configuration = conf.Configuration(None)
         vnx_utils.init_ops(self.configuration)
         self.configuration.storage_protocol = self.STORAGE_PROTOCOL
 
-    def tearDown(self):
-        super(TestISCSIAdapter, self).tearDown()
-
     @res_mock.patch_iscsi_adapter
     def test_validate_ports_iscsi(self, vnx_iscsi, mocked):
         all_iscsi_ports = vnx_iscsi.client.get_iscsi_targets()
@@ -1560,18 +1549,14 @@ class TestISCSIAdapter(test.TestCase):
         adapter.terminate_connection_cleanup.assert_called()
 
 
-class TestFCAdapter(test.TestCase):
+class TestFCAdapter(test_base.TestCase):
     STORAGE_PROTOCOL = common.PROTOCOL_FC
 
     def setUp(self):
         super(TestFCAdapter, self).setUp()
-        self.configuration = conf.Configuration(None)
         vnx_utils.init_ops(self.configuration)
         self.configuration.storage_protocol = self.STORAGE_PROTOCOL
 
-    def tearDown(self):
-        super(TestFCAdapter, self).tearDown()
-
     @res_mock.patch_fc_adapter
     def test_validate_ports_fc(self, vnx_fc, mocked):
         all_fc_ports = vnx_fc.client.get_fc_targets()
