@@ -227,7 +227,7 @@ class NetAppCmodeNfsDriverTestCase(test.TestCase):
             'pool_name': '10.10.10.10:/vola',
             'reserved_percentage': fake.RESERVED_PERCENTAGE,
             'max_over_subscription_ratio': fake.MAX_OVER_SUBSCRIPTION_RATIO,
-            'multiattach': False,
+            'multiattach': True,
             'total_capacity_gb': total_capacity_gb,
             'free_capacity_gb': free_capacity_gb,
             'netapp_dedupe_used_percent': 55.0,
@@ -247,6 +247,7 @@ class NetAppCmodeNfsDriverTestCase(test.TestCase):
             'consistencygroup_support': True,
             'consistent_group_snapshot_enabled': True,
             'replication_enabled': False,
+            'online_extend_support': False,
         }]
 
         expected[0].update({'QoS_support': cluster_credentials})
@@ -306,7 +307,7 @@ class NetAppCmodeNfsDriverTestCase(test.TestCase):
             self.driver.zapi_client, 'get_operational_lif_addresses',
             return_value=[fake.SHARE_IP])
         mock_resolve_hostname = self.mock_object(
-            na_utils, 'resolve_hostname', return_value=fake.SHARE_IP)
+            utils, 'resolve_hostname', return_value=fake.SHARE_IP)
         mock_get_flexvol = self.mock_object(
             self.driver.zapi_client, 'get_flexvol',
             return_value={'name': fake.NETAPP_VOLUME})
@@ -329,7 +330,7 @@ class NetAppCmodeNfsDriverTestCase(test.TestCase):
         self.mock_object(self.driver.zapi_client,
                          'get_operational_lif_addresses',
                          return_value=[])
-        self.mock_object(na_utils,
+        self.mock_object(utils,
                          'resolve_hostname',
                          return_value=fake.SHARE_IP)
 
@@ -343,7 +344,7 @@ class NetAppCmodeNfsDriverTestCase(test.TestCase):
         self.mock_object(self.driver.zapi_client,
                          'get_operational_lif_addresses',
                          return_value=[fake.SHARE_IP])
-        self.mock_object(na_utils,
+        self.mock_object(utils,
                          'resolve_hostname',
                          return_value=fake.SHARE_IP)
         side_effect = exception.VolumeBackendAPIException(data='fake_data')
@@ -874,8 +875,10 @@ class NetAppCmodeNfsDriverTestCase(test.TestCase):
     @mock.patch.object(image_utils, 'convert_image')
     @mock.patch.object(image_utils, 'qemu_img_info')
     @mock.patch('os.path.exists')
+    @mock.patch('cinder.privsep.path')
     def test_copy_from_img_service_qcow2_copyoffload_workflow_success(
-            self, mock_exists, mock_qemu_img_info, mock_cvrt_image):
+            self, mock_touch, mock_exists, mock_qemu_img_info,
+            mock_cvrt_image):
         drv = self.driver
         cinder_mount_point_base = '/opt/stack/data/cinder/mnt/'
         # To get the cinder mount point directory, we use:
@@ -932,11 +935,10 @@ class NetAppCmodeNfsDriverTestCase(test.TestCase):
                     '203.0.113.122', '/openstack/glance-flexvol1',
                     destination_copied_file, run_as_root=False,
                     check_exit_code=0
-                ),
-                mock.call('touch', cinder_mount_point, run_as_root=False)
+                )
             ]
         )
-        self.assertEqual(2, drv._execute.call_count)
+        self.assertEqual(1, drv._execute.call_count)
         self.assertEqual(2, drv._delete_file_at_path.call_count)
         self.assertEqual(1, drv._clone_file_dst_exists.call_count)
 
