@@ -16,6 +16,7 @@ import collections
 import copy
 import os
 import re
+import sys
 
 import ddt
 import mock
@@ -23,6 +24,7 @@ import mock
 from cinder import context
 from cinder import exception
 from cinder.image import image_utils
+from cinder.objects import fields
 from cinder import test
 from cinder.tests.unit import fake_snapshot
 from cinder.tests.unit import fake_volume
@@ -327,17 +329,19 @@ class RemoteFsSnapDriverTestCase(test.TestCase):
             {'status': 'creating', 'progress': '45%'},
             {'status': 'deleting'},
         ]
+        fake_snapshot = self._fake_snapshot
+        fake_snapshot.context = self.context
 
         with mock.patch.object(self._driver, '_do_create_snapshot') as \
                 mock_do_create_snapshot:
             self.assertRaises(exception.RemoteFSConcurrentRequest,
                               self._driver._create_snapshot_online,
-                              self._fake_snapshot,
+                              fake_snapshot,
                               self._fake_volume.name,
                               self._fake_snapshot_path)
 
         mock_do_create_snapshot.assert_called_once_with(
-            self._fake_snapshot, self._fake_volume.name,
+            fake_snapshot, self._fake_volume.name,
             self._fake_snapshot_path)
         self.assertEqual([mock.call(1), mock.call(1)],
                          mock_sleep.call_args_list)
@@ -586,6 +590,7 @@ class RemoteFsSnapDriverTestCase(test.TestCase):
               {'snapshots_exist': True},
               {'force_temp_snap': True})
     @ddt.unpack
+    @mock.patch.object(sys.modules['cinder.objects'], "Snapshot")
     @mock.patch.object(remotefs.RemoteFSSnapDriver, 'local_path')
     @mock.patch.object(remotefs.RemoteFSSnapDriver, '_snapshots_exist')
     @mock.patch.object(remotefs.RemoteFSSnapDriver, '_copy_volume_image')
@@ -603,16 +608,19 @@ class RemoteFsSnapDriverTestCase(test.TestCase):
                                   mock_copy_volume_image,
                                   mock_snapshots_exist,
                                   mock_local_path,
+                                  mock_obj_snap,
                                   snapshots_exist=False,
                                   force_temp_snap=False):
         drv = self._driver
 
+        # prepare test
         volume = fake_volume.fake_volume_obj(self.context)
         src_vref_id = '375e32b2-804a-49f2-b282-85d1d5a5b9e1'
         src_vref = fake_volume.fake_volume_obj(
             self.context,
             id=src_vref_id,
             name='volume-%s' % src_vref_id)
+        src_vref.context = self.context
 
         mock_snapshots_exist.return_value = snapshots_exist
         drv._always_use_temp_snap_when_cloning = force_temp_snap
@@ -621,27 +629,38 @@ class RemoteFsSnapDriverTestCase(test.TestCase):
                      'volume_type', 'metadata']
         Volume = collections.namedtuple('Volume', vol_attrs)
 
-        snap_attrs = ['volume_name', 'volume_size', 'name',
-                      'volume_id', 'id', 'volume']
-        Snapshot = collections.namedtuple('Snapshot', snap_attrs)
-
         volume_ref = Volume(id=volume.id,
+                            metadata=volume.metadata,
                             name=volume.name,
-                            status=volume.status,
                             provider_location=volume.provider_location,
+                            status=volume.status,
                             size=volume.size,
-                            volume_type=volume.volume_type,
-                            metadata=volume.metadata)
+                            volume_type=volume.volume_type,)
 
-        snap_ref = Snapshot(volume_name=volume.name,
-                            name='clone-snap-%s' % src_vref.id,
-                            volume_size=src_vref.size,
-                            volume_id=src_vref.id,
-                            id='tmp-snap-%s' % src_vref.id,
-                            volume=src_vref)
+        snap_args_creation = {
+            'volume_id': src_vref.id,
+            'user_id': None,
+            'project_id': None,
+            'status': fields.SnapshotStatus.CREATING,
+            'progress': '0%',
+            'volume_size': src_vref.size,
+            'display_name': 'tmp-snap-%s' % src_vref['id'],
+            'display_description': None,
+            'volume_type_id': src_vref.volume_type_id,
+            'encryption_key_id': None,
+        }
+        snap_args_deletion = snap_args_creation.copy()
+        snap_args_deletion["status"] = fields.SnapshotStatus.DELETED
+        snap_args_deletion["deleted"] = True
 
+        mock_obj_snap.return_value = mock.Mock()
+        mock_obj_snap.return_value.create = mock.Mock()
+        # end of prepare test
+
+        # run test
         drv.create_cloned_volume(volume, src_vref)
 
+        # evaluate test
         exp_acceptable_states = ['available', 'backing-up', 'downloading']
         mock_validate_state.assert_called_once_with(
             src_vref.status,
@@ -649,10 +668,14 @@ class RemoteFsSnapDriverTestCase(test.TestCase):
             obj_description='source volume')
 
         if snapshots_exist or force_temp_snap:
-            mock_create_snapshot.assert_called_once_with(snap_ref)
+            mock_obj_snap.return_value.create.assert_called_once_with()
+            mock_obj_snap.assert_called_once_with(
+                context=self.context, **snap_args_creation)
+            mock_create_snapshot.assert_called_once_with(
+                mock_obj_snap.return_value)
             mock_copy_volume_from_snapshot.assert_called_once_with(
-                snap_ref, volume_ref, volume['size'])
-            self.assertTrue(mock_delete_snapshot.called)
+                mock_obj_snap.return_value, volume_ref, volume['size'])
+            mock_delete_snapshot.called_once_with(snap_args_deletion)
         else:
             self.assertFalse(mock_create_snapshot.called)
 
@@ -663,8 +686,7 @@ class RemoteFsSnapDriverTestCase(test.TestCase):
                 mock_local_path.return_value)
             mock_local_path.assert_has_calls(
                 [mock.call(src_vref), mock.call(volume_ref)])
-            mock_extend_volume.assert_called_once_with(volume_ref,
-                                                       volume.size)
+            mock_extend_volume.assert_called_once_with(volume_ref, volume.size)
 
     @mock.patch('shutil.copyfile')
     @mock.patch.object(remotefs.RemoteFSSnapDriver, '_set_rw_permissions')
