@@ -145,7 +145,9 @@ SIO_MAX_OVERSUBSCRIPTION_RATIO = 10.0
 class ScaleIODriver(driver.VolumeDriver):
     """Cinder ScaleIO Driver
 
-    ScaleIO Driver version history:
+    .. code-block:: none
+
+      ScaleIO Driver version history:
         2.0.1: Added support for SIO 1.3x in addition to 2.0.x
         2.0.2: Added consistency group support to generic volume groups
         2.0.3: Added cache for storage pool and protection domains info
@@ -232,6 +234,10 @@ class ScaleIODriver(driver.VolumeDriver):
             'bandwidthLimit': None,
         }
 
+    @staticmethod
+    def get_driver_options():
+        return scaleio_opts
+
     def check_for_setup_error(self):
         # make sure both domain name and id are not specified
         if (self.configuration.sio_protection_domain_name
@@ -320,7 +326,7 @@ class ScaleIODriver(driver.VolumeDriver):
             if not padded:
                 LOG.warning("Zero padding is disabled for pool, %s. "
                             "This could lead to existing data being "
-                            "accessible on new thick provisioned volumes. "
+                            "accessible on new provisioned volumes. "
                             "Consult the ScaleIO product documentation "
                             "for information on how to enable zero padding "
                             "and prevent this from occurring.",
@@ -600,10 +606,9 @@ class ScaleIODriver(driver.VolumeDriver):
             provisioning = "ThickProvisioned"
 
         allowed = self._is_volume_creation_safe(protection_domain_name,
-                                                storage_pool_name,
-                                                provisioning)
+                                                storage_pool_name)
         if not allowed:
-            # Do not allow thick volume creation on this backend.
+            # Do not allow volume creation on this backend.
             # Volumes may leak data between tenants.
             LOG.error("Volume creation rejected due to "
                       "zero padding being disabled for pool, %s:%s. "
@@ -784,7 +789,15 @@ class ScaleIODriver(driver.VolumeDriver):
                  {'volname': volume_id,
                   'snapname': snapname})
 
-        return self._snapshot_volume(volume_id, snapname)
+        ret = self._snapshot_volume(volume_id, snapname)
+        if volume.size > snapshot.volume_size:
+            LOG.info("Extending volume %(vol)s to size %(size)s",
+                     {'vol': ret['provider_id'],
+                      'size': volume.size})
+            self._extend_volume(ret['provider_id'],
+                                snapshot.volume_size, volume.size)
+
+        return ret
 
     @staticmethod
     def _get_headers():
