@@ -26,6 +26,7 @@ import six
 from cinder import coordination
 from cinder import exception
 from cinder.i18n import _
+from cinder.objects import fields
 from cinder.volume import utils as vol_utils
 from cinder.volume import volume_types
 from cinder.zonemanager import utils as zm_utils
@@ -179,6 +180,18 @@ def get_pool_name(volume):
     return vol_utils.extract_host(volume.host, 'pool')
 
 
+def get_pool_name_from_host(host):
+    return vol_utils.extract_host(host['host'], 'pool')
+
+
+def get_backend_name_from_volume(volume):
+    return vol_utils.extract_host(volume.host, 'backend')
+
+
+def get_backend_name_from_host(host):
+    return vol_utils.extract_host(host['host'], 'backend')
+
+
 def get_extra_spec(volume, spec_key):
     spec_value = None
     type_id = volume.volume_type_id
@@ -304,3 +317,18 @@ def lock_if(condition, lock_name):
         return coordination.synchronized(lock_name)
     else:
         return functools.partial
+
+
+def is_multiattach_to_host(volume_attachment, host_name):
+    # When multiattach is enabled, a volume could be attached to two or more
+    # instances which are hosted on one nova host.
+    # Because unity cannot recognize the volume is attached to two or more
+    # instances, we should keep the volume attached to the nova host until
+    # the volume is detached from the last instance.
+    if not volume_attachment:
+        return False
+
+    attachment = [a for a in volume_attachment
+                  if a.attach_status == fields.VolumeAttachStatus.ATTACHED and
+                  a.attached_host == host_name]
+    return len(attachment) > 1
