@@ -32,10 +32,10 @@ import uuid
 
 from oslo_config import cfg
 from oslo_log import log as logging
+from oslo_log import versionutils
 from oslo_utils import importutils
 from oslo_utils import units
 
-
 from cinder import exception
 from cinder.i18n import _
 from cinder import interface
@@ -185,6 +185,10 @@ class DrbdManageBaseDriver(driver.VolumeDriver):
         CS_DISKLESS = dm_const.CSTATE_PREFIX + dm_const.FLAG_DISKLESS
         CS_UPD_CON = dm_const.CSTATE_PREFIX + dm_const.FLAG_UPD_CON
 
+    @staticmethod
+    def get_driver_options():
+        return drbd_opts
+
     def dbus_connect(self):
         self.odm = dbus.SystemBus().get_object(self.drbdmanage_dbus_name,
                                                self.drbdmanage_dbus_interface)
@@ -229,6 +233,11 @@ class DrbdManageBaseDriver(driver.VolumeDriver):
     def do_setup(self, context):
         """Any initialization the volume driver does while starting."""
         super(DrbdManageBaseDriver, self).do_setup(context)
+
+        msg = _("The DRBD Manage driver is moving to maintenance mode "
+                "in the Stein release and will be removed in T release.")
+        versionutils.report_deprecated_feature(LOG, msg)
+
         self.dbus_connect()
 
     def check_for_setup_error(self):
@@ -278,10 +287,10 @@ class DrbdManageBaseDriver(driver.VolumeDriver):
 
     # DRBDmanage works in kiB units; Cinder uses GiB.
     def _vol_size_to_dm(self, size):
-        return size * units.Gi / units.Ki
+        return size * units.Gi // units.Ki
 
     def _vol_size_to_cinder(self, size):
-        return size * units.Ki / units.Gi
+        return size * units.Ki // units.Gi
 
     def is_clean_volume_name(self, name, prefix):
         try:
@@ -527,8 +536,7 @@ class DrbdManageBaseDriver(driver.VolumeDriver):
         if not drbd_vol:
             props = self._priv_hash_from_volume(volume)
             # TODO(PM): properties - redundancy, etc
-            res = self.call_or_reconnect(self.odm.create_volume,
-                                         d_res_name,
+            res = self.odm.create_volume(d_res_name,
                                          self._vol_size_to_dm(volume['size']),
                                          props)
             self._check_result(res)
@@ -895,7 +903,7 @@ class DrbdManageDrbdDriver(DrbdManageBaseDriver):
         return {
             'driver_volume_type': 'drbd',
             'data': {
-                'provider_location': ' '.join('drbd', nodename),
+                'provider_location': ' '.join(('drbd', nodename)),
                 'device': volume_path,
                 # TODO(pm): consistency groups
                 'devices': [volume_path],
