@@ -44,9 +44,6 @@ class RestClient(object):
                                         self.configuration.storage_pools)
         self.iscsi_info = kwargs.get('iscsi_info',
                                      self.configuration.iscsi_info)
-        self.iscsi_default_target_ip = kwargs.get(
-            'iscsi_default_target_ip',
-            self.configuration.iscsi_default_target_ip)
         self.session = None
         self.url = None
         self.device_id = None
@@ -828,29 +825,25 @@ class RestClient(object):
     def find_chap_info(self, iscsi_info, initiator_name):
         """Find CHAP info from xml."""
         chapinfo = None
-        for ini in iscsi_info:
-            if ini['Name'] == initiator_name:
-                if 'CHAPinfo' in ini:
-                    chapinfo = ini['CHAPinfo']
-                    break
-
+        ini = iscsi_info['initiators'].get(initiator_name)
+        if ini and ini.get('CHAPinfo'):
+            chapinfo = ini['CHAPinfo']
         return chapinfo
 
     def _find_alua_info(self, iscsi_info, initiator_name):
         """Find ALUA info from xml."""
         multipath_type = 0
-        for ini in iscsi_info:
-            if ini['Name'] == initiator_name:
-                if 'ALUA' in ini:
-                    if ini['ALUA'] != '1' and ini['ALUA'] != '0':
-                        msg = (_(
-                            'Invalid ALUA value. '
-                            'ALUA value must be 1 or 0.'))
-                        LOG.error(msg)
-                        raise exception.InvalidInput(msg)
-                    else:
-                        multipath_type = ini['ALUA']
-                        break
+        ini = iscsi_info['initiators'].get(initiator_name)
+        if ini and ini.get('ALUA'):
+            if ini['ALUA'] != '1' and ini['ALUA'] != '0':
+                msg = (_(
+                    'Invalid ALUA value. '
+                    'ALUA value must be 1 or 0.'))
+                LOG.error(msg)
+                raise exception.InvalidInput(msg)
+            else:
+                multipath_type = ini['ALUA']
+
         return multipath_type
 
     def _use_chap(self, chapinfo, initiator_name, host_id):
@@ -1297,9 +1290,10 @@ class RestClient(object):
         portgroup_id = None
 
         if multipath:
-            for ini in self.iscsi_info:
-                if ini['Name'] == initiator:
-                    portgroup = ini.get('TargetPortGroup')
+            ini = self.iscsi_info['initiators'].get(initiator)
+            if ini and ini.get('TargetPortGroup'):
+                portgroup = ini['TargetPortGroup']
+
             if portgroup:
                 portgroup_id = self.get_tgt_port_group(portgroup)
                 temp_tgt_ips = self._get_tgt_ip_from_portgroup(portgroup_id)
@@ -1340,14 +1334,13 @@ class RestClient(object):
 
     def _get_target_ip(self, initiator):
         target_ips = []
-        for ini in self.iscsi_info:
-            if ini['Name'] == initiator:
-                if ini.get('TargetIP'):
-                    target_ips.append(ini.get('TargetIP'))
+        ini = self.iscsi_info['initiators'].get(initiator)
+        if ini and ini.get('TargetIP'):
+            target_ips.append(ini['TargetIP'])
 
         # If not specify target IP for some initiators, use default IP.
         if not target_ips:
-            default_target_ips = self.iscsi_default_target_ip
+            default_target_ips = self.iscsi_info['default_target_ips']
             if default_target_ips:
                 target_ips.append(default_target_ips[0])
 
@@ -1374,7 +1367,7 @@ class RestClient(object):
             msg = (_(
                 "Can't find valid IP from rest, please check it on storage."))
             LOG.error(msg)
-            raise exception.VolumeBackendAPIException(data = msg)
+            raise exception.VolumeBackendAPIException(data=msg)
 
         if 'data' in result:
             for item in result['data']:
@@ -1423,7 +1416,7 @@ class RestClient(object):
 
         return target_iqn
 
-    def create_qos_policy(self, qos, lun_id):
+    def create_qos(self, qos, lun_id):
         # Get local time.
         localtime = time.strftime('%Y%m%d%H%M%S', time.localtime(time.time()))
         # Package QoS name.
@@ -1447,8 +1440,7 @@ class RestClient(object):
 
         return result['data']['ID']
 
-    def delete_qos_policy(self, qos_id):
-        """Delete a QoS policy."""
+    def delete_qos(self, qos_id):
         url = "/ioclass/" + qos_id
         data = {"TYPE": "230", "ID": qos_id}
 
@@ -2374,7 +2366,53 @@ class RestClient(object):
         result = self.call(url, None, "GET", log_filter_flag=True)
 
         if result['error']['code'] != 0:
-            raise
+            raise Exception(_('Failed to get object count.'))
 
         if result.get("data"):
             return result.get("data").get("COUNT")
+
+    def get_lun_info_by_name(self, name):
+        url = "/lun?filter=NAME::%s" % name
+        result = self.call(url, None, "GET")
+
+        msg = _('Get lun by name %s error.') % name
+        self._assert_rest_result(result, msg)
+
+        if result.get('data'):
+            return result['data'][0]
+
+    def get_lun_info_by_id(self, lun_id):
+        url = "/lun/" + lun_id
+        result = self.call(url, None, "GET")
+
+        msg = _('Get lun by id %s error.') % lun_id
+        self._assert_rest_result(result, msg)
+
+        return result['data']
+
+    def get_snapshot_info_by_name(self, name):
+        url = "/snapshot?filter=NAME::%s" % name
+        result = self.call(url, None, "GET")
+
+        msg = _('Get snapshot by name %s error.') % name
+        self._assert_rest_result(result, msg)
+
+        if result.get('data'):
+            return result['data'][0]
+
+    def get_snapshot_info_by_id(self, snapshot_id):
+        url = "/snapshot/" + snapshot_id
+        result = self.call(url, None, "GET")
+
+        msg = _('Get snapshot by id %s error.') % snapshot_id
+        self._assert_rest_result(result, msg)
+
+        return result['data']
+
+    def update_qos_luns(self, qos_id, lun_list):
+        url = "/ioclass/" + qos_id
+        data = {"LUNLIST": lun_list}
+        result = self.call(url, data, "PUT")
+
+        msg = _('Update luns of qos %s error.') % qos_id
+        self._assert_rest_result(result, msg)
