@@ -17,20 +17,22 @@ from oslo_config import cfg
 
 from cinder.volume import configuration as conf
 
+POLL_RETRIES = 5
+DEFAULT_ISCSI_PORT = 3260
+DEFAULT_HOST_GROUP = 'all'
+DEFAULT_TARGET_GROUP = 'all'
+
 NEXENTA_EDGE_OPTS = [
     cfg.StrOpt('nexenta_nbd_symlinks_dir',
                default='/dev/disk/by-path',
                help='NexentaEdge logical path of directory to store symbolic '
                     'links to NBDs'),
-    cfg.StrOpt('nexenta_rest_address',
-               default='',
-               help='IP address of NexentaEdge management REST API endpoint'),
     cfg.StrOpt('nexenta_rest_user',
                default='admin',
-               help='User name to connect to NexentaEdge'),
+               help='User name to connect to NexentaEdge.'),
     cfg.StrOpt('nexenta_rest_password',
                default='nexenta',
-               help='Password to connect to NexentaEdge',
+               help='Password to connect to NexentaEdge.',
                secret=True),
     cfg.StrOpt('nexenta_lun_container',
                default='',
@@ -39,19 +41,42 @@ NEXENTA_EDGE_OPTS = [
                default='',
                help='NexentaEdge iSCSI service name'),
     cfg.StrOpt('nexenta_client_address',
+               deprecated_for_removal=True,
+               deprecated_reason='iSCSI target address should now be set using'
+                                 ' the common param target_ip_address.',
                default='',
                help='NexentaEdge iSCSI Gateway client '
                'address for non-VIP service'),
+    cfg.IntOpt('nexenta_iops_limit',
+               default=0,
+               help='NexentaEdge iSCSI LUN object IOPS limit'),
     cfg.IntOpt('nexenta_chunksize',
                default=32768,
-               help='NexentaEdge iSCSI LUN object chunk size')
+               help='NexentaEdge iSCSI LUN object chunk size'),
+    cfg.IntOpt('nexenta_replication_count',
+               default=3,
+               help='NexentaEdge iSCSI LUN object replication count.'),
+    cfg.BoolOpt('nexenta_encryption',
+                default=False,
+                help='Defines whether NexentaEdge iSCSI LUN object '
+                     'has encryption enabled.')
 ]
 
 NEXENTA_CONNECTION_OPTS = [
+    cfg.StrOpt('nexenta_rest_address',
+               deprecated_for_removal=True,
+               deprecated_reason='Rest address should now be set using '
+                                 'the common param depending on driver type, '
+                                 'san_ip or nas_host',
+               default='',
+               help='IP address of NexentaEdge management REST API endpoint'),
     cfg.StrOpt('nexenta_host',
                default='',
                help='IP address of Nexenta SA'),
     cfg.IntOpt('nexenta_rest_port',
+               deprecated_for_removal=True,
+               deprecated_reason='Rest address should now be set using '
+                                 'the common param san_api_port.',
                default=0,
                help='HTTP(S) port to connect to Nexenta REST API server. '
                     'If it is equal zero, 8443 for HTTPS and 8080 for HTTP '
@@ -63,31 +88,59 @@ NEXENTA_CONNECTION_OPTS = [
     cfg.BoolOpt('nexenta_use_https',
                 default=True,
                 help='Use secure HTTP for REST connection (default True)'),
+    cfg.BoolOpt('nexenta_lu_writebackcache_disabled',
+                default=False,
+                help='Postponed write to backing store or not'),
     cfg.StrOpt('nexenta_user',
+               deprecated_for_removal=True,
+               deprecated_reason='Common user parameters should be used '
+                                 'depending on the driver type: '
+                                 'san_login or nas_login',
                default='admin',
                help='User name to connect to Nexenta SA'),
     cfg.StrOpt('nexenta_password',
+               deprecated_for_removal=True,
+               deprecated_reason='Common password parameters should be used '
+                                 'depending on the driver type: '
+                                 'san_password or nas_password',
                default='nexenta',
                help='Password to connect to Nexenta SA',
                secret=True),
 ]
 
 NEXENTA_ISCSI_OPTS = [
+    cfg.StrOpt('nexenta_iscsi_target_portal_groups',
+               default='',
+               help='Nexenta target portal groups'),
+    cfg.StrOpt('nexenta_iscsi_target_portals',
+               default='',
+               help='Comma separated list of portals for NexentaStor5, in '
+                    'format of IP1:port1,IP2:port2. Port is optional, '
+                    'default=3260. Example: 10.10.10.1:3267,10.10.1.2'),
+    cfg.StrOpt('nexenta_iscsi_target_host_group',
+               default='all',
+               help='Group of hosts which are allowed to access volumes'),
     cfg.IntOpt('nexenta_iscsi_target_portal_port',
                default=3260,
                help='Nexenta target portal port'),
+    cfg.IntOpt('nexenta_luns_per_target',
+               default=100,
+               help='Amount of iSCSI LUNs per each target'),
     cfg.StrOpt('nexenta_volume',
                default='cinder',
                help='SA Pool that holds all volumes'),
     cfg.StrOpt('nexenta_target_prefix',
-               default='iqn.1986-03.com.sun:02:cinder-',
+               default='iqn.1986-03.com.sun:02:cinder',
                help='IQN prefix for iSCSI targets'),
     cfg.StrOpt('nexenta_target_group_prefix',
-               default='cinder/',
+               default='cinder',
                help='Prefix for iSCSI target groups on SA'),
+    cfg.StrOpt('nexenta_host_group_prefix',
+               default='cinder',
+               help='Prefix for iSCSI host groups on SA'),
     cfg.StrOpt('nexenta_volume_group',
                default='iscsi',
-               help='Volume group for ns5'),
+               help='Volume group for NexentaStor5 iSCSI'),
 ]
 
 NEXENTA_NFS_OPTS = [
@@ -120,6 +173,9 @@ NEXENTA_DATASET_OPTS = [
                default='off',
                choices=['on', 'off', 'sha256', 'verify', 'sha256, verify'],
                help='Deduplication value for new ZFS folders.'),
+    cfg.StrOpt('nexenta_folder',
+               default='',
+               help='A folder where cinder created datasets will reside.'),
     cfg.StrOpt('nexenta_dataset_description',
                default='',
                help='Human-readable description for the folder.'),
