@@ -15,7 +15,7 @@ from oslo_log import log as logging
 
 from cinder import exception
 from cinder.i18n import _
-from cinder import utils
+import cinder.privsep.targets.scst
 from cinder.volume.targets import iscsi
 from cinder.volume import utils as vutils
 
@@ -37,7 +37,7 @@ class SCSTAdm(iscsi.ISCSITarget):
         self.remove_initiator_iqn = None
 
     def scst_execute(self, *args):
-        return utils.execute('scstadmin', *args, run_as_root=True)
+        return cinder.privsep.targets.scst.run_scstadmin(*args)
 
     def validate_connector(self, connector):
         # iSCSI drivers require the initiator information
@@ -231,7 +231,8 @@ class SCSTAdm(iscsi.ISCSITarget):
         return tid
 
     def _iscsi_location(self, ip, target, iqn, lun=None):
-        return "%s:%s,%s %s %s" % (ip, self.configuration.target_port,
+        return "%s:%s,%s %s %s" % (vutils.sanitize_host(ip),
+                                   self.configuration.target_port,
                                    target, iqn, lun)
 
     def _get_iscsi_name(self, volume):
@@ -310,7 +311,7 @@ class SCSTAdm(iscsi.ISCSITarget):
             self.show_target(iscsi_target, iqn)
 
         except Exception:
-            LOG.error("Skipping remove_export. No iscsi_target is"
+            LOG.error("Skipping remove_export. No iscsi_target is "
                       "presently exported for volume: %s", volume['id'])
             return
         vol = self.db.volume_get(context, volume['id'])
